==> selenide-7.4.3-sources.jar: com/codeborne/selenide/impl/WebDriverContainer.java <==
package com.codeborne.selenide.impl;

import com.codeborne.selenide.DownloadsFolder;
import com.codeborne.selenide.proxy.SelenideProxyServer;
import org.openqa.selenium.Proxy;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.support.events.WebDriverListener;

import javax.annotation.CheckReturnValue;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;

@ParametersAreNonnullByDefault
public interface WebDriverContainer {
  void addListener(WebDriverListener listener);
  void removeListener(WebDriverListener listener);
  void setWebDriver(WebDriver webDriver);
  void setWebDriver(WebDriver webDriver, @Nullable SelenideProxyServer selenideProxy);
  void setWebDriver(WebDriver webDriver, @Nullable SelenideProxyServer selenideProxy, DownloadsFolder browserDownloadsFolder);


  @CheckReturnValue
  @Nonnull
  WebDriver getWebDriver();

  @CheckReturnValue
  @Nonnull
  SelenideProxyServer getProxyServer();

  void setProxy(@Nullable Proxy webProxy);

  @CheckReturnValue
  @Nonnull
  WebDriver getAndCheckWebDriver();

  @CheckReturnValue
  @Nullable
  DownloadsFolder getBrowserDownloadsFolder();

  void closeWindow();
  void closeWebDriver();
  boolean hasWebDriverStarted();

  void using(WebDriver driver, @Nullable SelenideProxyServer proxy, @Nullable DownloadsFolder downloadsFolder, Runnable lambda);
  void inNewBrowser(Runnable lambda);

  void clearBrowserCache();

  @CheckReturnValue
  @Nonnull
  String getPageSource();

  @CheckReturnValue
  @Nonnull
  String getCurrentUrl();

  @CheckReturnValue
  @Nonnull
  String getCurrentFrameUrl();
}

==> selenide-7.12.0-sources.jar: com/codeborne/selenide/impl/WebDriverContainer.java <==
package com.codeborne.selenide.impl;

import com.codeborne.selenide.Config;
import com.codeborne.selenide.DownloadsFolder;
import com.codeborne.selenide.proxy.SelenideProxyServer;
import org.jspecify.annotations.Nullable;
import org.openqa.selenium.Proxy;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.logging.LogEntry;
import org.openqa.selenium.support.events.WebDriverListener;

import java.util.List;

public interface WebDriverContainer {
  void addListener(WebDriverListener listener);
  void removeListener(WebDriverListener listener);
  void setWebDriver(WebDriver webDriver);
  void setWebDriver(WebDriver webDriver, @Nullable SelenideProxyServer selenideProxy);
  void setWebDriver(WebDriver webDriver, @Nullable SelenideProxyServer selenideProxy, DownloadsFolder browserDownloadsFolder);

  WebDriver getWebDriver();

  SelenideProxyServer getProxyServer();

  void setProxy(@Nullable Proxy webProxy);

  WebDriver getAndCheckWebDriver();

  @Nullable
  DownloadsFolder getBrowserDownloadsFolder();

  List<LogEntry> getBrowserLogs();

  void closeWindow();
  void closeWebDriver();
  boolean hasWebDriverStarted();

  void using(WebDriver driver, @Nullable SelenideProxyServer proxy, @Nullable DownloadsFolder downloadsFolder, Runnable lambda);
  void inNewBrowser(Runnable lambda);
  void inNewBrowser(Config config, Runnable lambda);

  void clearBrowserCache();

  @Nullable
  String getPageSource();

  @Nullable
  String getCurrentUrl();

  String getCurrentFrameUrl();
}
